//******************************************************************************
//
// File:    LC4Encrypt.java
// Package: ---
// Unit:    Class LC4Encrypt
//
// This Java source file is copyright (C) 2017 by Alan Kaminsky. All rights
// reserved. For further information, contact the author, Alan Kaminsky, at
// ark@cs.rit.edu.
//
// This Java source file is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 3 of the License, or (at your option) any
// later version.
//
// This Java source file is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// A copy of the GNU General Public License is provided in the file gpl.txt. You
// may also obtain a copy of the GNU General Public License on the World Wide
// Web at http://www.gnu.org/licenses/gpl.html.
//
//******************************************************************************

/**
 * Class LC4Encrypt is a main program that encrypts a message using the LC4
 * cipher. The program prints the ciphertext for the given key, nonce, and
 * plaintext. If the <TT>-v</TT> flag is specified, the program prints the state
 * of the encryption algorithm at each step.
 * <P>
 * Usage: <TT>java LC4Encrypt [-v] <I>key</I> <I>nonce</I> <I>plaintext</I></TT>
 *
 * @author  Alan Kaminsky
 * @version 23-Mar-2017
 * 
 * modified by Anna Lena Rotthaler
 * 01-Oct-2017
 * Weakened version without nonce added
 */

 public class LC4Encrypt
	{

// Prevent construction.

	private LC4Encrypt()
		{
		}

// Main program.

	/**
	 * Main program.
	 */
	public static void main
		(String[] args)
		{
		if(args.length == 2)
		{
			LC4 cipher = new LC4();
			System.out.println (cipher.encrypt (args[0], args[1]));
		}
		else if (args.length == 3 && !args[0].equals("-v"))
			{
			LC4 cipher = new LC4();
			System.out.println (cipher.encrypt (args[0], args[1], args[2]));
			}
		else if (args.length == 3 && args[0].equals("-v"))
			{
			LC4 cipher = new LC4();
			cipher.trace = true;
			System.out.println (cipher.encrypt (args[1], args[2]));	
			}			
		else if (args.length == 4 && args[0].equals ("-v"))
			{
			LC4 cipher = new LC4();
			cipher.trace = true;
			System.out.println (cipher.encrypt (args[1], args[2], args[3]));
			}
		else
			usage();
		}

// Hidden operations.

	/**
	 * Print a usage message and exit.
	 */
	private static void usage()
		{
		System.err.println ("Usage: java LC4Encrypt [-v] <key> <nonce> <plaintext>");
		System.err.println ("Usage weakened version (no nonce): java LC4Encrypt [-v] <key> <plaintext>");
		System.exit (1);
		}

	}
